@@ -3,12 +3,11 @@ use warnings;
 
 =head1 NAME
 
-Algorithm::Evolutionary::Individual::Any - Wrapper around any Perl data structure, turns it into a I<Chromosome> 
+    Algorithm::Evolutionary::Individual::Any - Wrapper around any Perl class, turns into a I<Chromosome> any class
 
 =head1 SYNOPSIS
 
     use Algorithm::Evolutionary::Individual::Any;
-    use Class::Name; # Your class here; it's required if not included anyways
 
     my $indi = new Algorithm::Evolutionary::Individual::Any Class::Name $class_args ; 
 
@@ -21,16 +20,14 @@ L<Algorithm::Evolutionary::Individual::Base>
 
 =head1 DESCRIPTION
 
-Bitstring Individual for a Genetic Algorithm. Used, for instance, in a
-canonical GA. That does not mean it can be used for mutation or
-crossover; normally you'll have to write your own classes 
+Bitstring Individual for a Genetic Algorithm. Used, for instance, in a canonical GA
 
 =cut
 
 package Algorithm::Evolutionary::Individual::Any;
 use Carp;
 
-our ($VERSION) =  ( '$Revision: 3.0 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) =  ( '$Revision: 2.1 $ ' =~ /(\d+\.\d+)/ );
 
 use base 'Algorithm::Evolutionary::Individual::Base';
 
@@ -38,9 +35,7 @@ use base 'Algorithm::Evolutionary::Individual::Base';
 
 =head2 new( $base_class, $base_class_args )
 
-Creates a new individual by instantiating one of the given class with
-the arguments also issued here, which are forwarded to the class
-constructor.
+Creates a new individual by instantiating one of the given class with the arguments also issued here, which are forwarded to the class constructor.
 
 =cut
 
@@ -54,7 +49,7 @@ sub new {
     eval "require $base_class" || croak "Can't find $base_class Module";
   }
   
-  my $inner_self = $base_class->new( $base_class_args ) || croak "Something is wrong when creating $base_class: $@\n";
+  my $inner_self = $base_class->new( $base_class_args );
   $self->{'_inner'} = $inner_self;
   return $self;
 }
@@ -62,9 +57,7 @@ sub new {
 
 =head2 Atom([$index]) 
 
-No matter what kind of underlying structure is there, it will return the wrapped object. You can
-subclass and overload, however, but then you earn nothing to use this
-class; you're better off creating a new one altogether.
+No matter what you write, it will return the object wrapped
 
 =cut 
 
@@ -91,4 +84,10 @@ sub size {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
+  CVS Info: $Date: 2009/02/04 20:43:14 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/Any.pm,v 2.1 2009/02/04 20:43:14 jmerelo Exp $ 
+  $Author: jmerelo $ 
+  $Revision: 2.1 $
+  $Name $
+
 =cut
