@@ -1,6 +1,8 @@
 use strict; #-*-cperl-*-
 use warnings;
 
+use lib qw( ../../../../lib );
+
 =head1 NAME
 
 Algorithm::Evolutionary::Individual::Base - Base class for chromosomes that knows how to build them, and has some helper methods.
@@ -29,12 +31,11 @@ Base class for individuals, that is, "chromosomes" in evolutionary computation a
 
 package Algorithm::Evolutionary::Individual::Base;
 
-use XML::Parser;
-use XML::Parser::EasyTree;
+use Algorithm::Evolutionary::Utils qw(parse_xml);
 use YAML qw(Dump Load LoadFile);
 use Carp;
 
-our ($VERSION) = ( '$Revision: 1.13 $ ' =~ / (\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 2.5 $ ' =~ / (\d+\.\d+)/ );
 
 use constant MY_OPERATORS => qw(None);
 
@@ -112,34 +113,32 @@ about is C<require>d in runtime.
 sub fromXML {
   my $class = shift;
   my $xml = shift || croak "XML fragment missing ";
+  my $fragment; # Inner part of the XML
   if ( ref $xml eq ''  ) { #We are receiving a string, parse it
-    my $p=new XML::Parser(Style=>'EasyTree');
-    $XML::Parser::EasyTree::Noempty=1;
-    $xml = $p->parse($xml);
+    $xml = parse_xml ($xml );
+    croak "Incorrect XML fragment" if !$xml->{'indi'}; #
+    $fragment = $xml->{'indi'};
+  } elsif ( $xml->{'indi'} ) { # parsed externally, as in general.t
+    $fragment = $xml->{'indi'};
+  } else { #parsed fragment
+    $fragment = $xml;
   }
 
-  my $thisClassName = $xml->[0]{attrib}{type};
+  my $thisClassName = $fragment->{'-type'};
   if ( $class eq  __PACKAGE__ ) { #Deduct class from the XML
     $class = $thisClassName || shift || croak "Class name missing";
   }
 
   #Calls new, adds preffix if it's not there
   my $self = Algorithm::Evolutionary::Individual::Base::new( $class );
-  ($self->Fitness( $xml->[0]{attrib}{fitness} ) )if defined $xml->[0]{attrib}{fitness};
+  ($self->Fitness( $fragment->{'fitness'} ) ) if defined $fragment->{'fitness'};
  
   $class = ref $self;
   eval "require $class"  || croak "Can't find $class\.pm Module";
   no strict qw(refs); # To be able to check if a ref exists or not
-  my $fragment;
-  if ( scalar @$xml > 1 ) { #Received from experiment or suchlike; already processed
-    $fragment = $xml;
-  }  else {
-    $fragment = $xml->[0]{content};
-  } 
-  for (@$fragment ) {
-    if ( defined(  $_->{content} ) ) { 
-      $self->addAtom($_->{content}->[0]->{content}); #roundabout way of adding the content of the stuff
-    } 
+
+  for (@{$fragment->{'atom'}} ) {
+    $self->addAtom($_); #roundabout way of adding the content of the stuff
   }
   return $self;
 }
@@ -166,11 +165,11 @@ sub fromParam {
   my $thisClass;
   
   my %params;
-  for ( @$xml ) {
-    if ( $_->{attrib}{name} eq 'type' ) {
-      $thisClass = $_->{attrib}{value}
+  for ( @{$xml->{'param'}} ) {
+    if ( $_->{'-name'} eq 'type' ) {
+      $thisClass = $_->{'-value'}
     } else {
-      $params{ $_->{attrib}{name} } = $_->{attrib}{value};
+      $params{ $_->{'-name'} } = $_->{'-value'};
     }
   }
   $thisClass = "Algorithm::Evolutionary::Individual::$thisClass" if $thisClass !~ /Algorithm::Evolutionary/;
@@ -222,7 +221,7 @@ sub as_string {
 
 =head2 as_string_with_fitness( [$separator] )
 
-Prints it as a string followeb by fitness. Separator by default is C<;>
+Prints it as a string followed by fitness. Separator by default is C<;>
 
 =cut
 
@@ -271,7 +270,7 @@ sub my_operators {
 
 =head2 evaluate( $fitness )
 
-Evaluates using the $fitness function given. Can be a Fitness object or a ref-to-sub
+Evaluates using the $fitness thingy given. Can be a L<Algorithm::Evolutionary::Fitness::Base|Fitness> object or a ref-to-sub
 
 =cut
 
@@ -341,10 +340,10 @@ L<Algorithm::Evolutionary::Individual::Bit_Vector>
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2008/07/27 08:09:32 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/Base.pm,v 1.13 2008/07/27 08:09:32 jmerelo Exp $ 
+  CVS Info: $Date: 2009/02/21 12:33:48 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/Base.pm,v 2.5 2009/02/21 12:33:48 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.13 $
+  $Revision: 2.5 $
   $Name $
 
 =cut
